@@ -5,5 +5,5 @@ from django.urls import re_path
 from core_exporters_app import urls as core_exporters_app_urls
 
 urlpatterns = [
-    re_path(r'^admin/', include(admin.site.urls)),
+    re_path(r"^admin/", include(admin.site.urls)),
 ] + core_exporters_app_urls.urlpatterns
